<?php

namespace Superrobota\Tableview\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Tableview\Models\Tableview;

class TableviewPolicy
{

    /**
     * Determine if the given user can view the tableview.
     *
     * @param UserPolicy $user
     * @param Tableview $tableview
     *
     * @return bool
     */
    public function view(UserPolicy $user, Tableview $tableview)
    {
        if ($user->canDo('tableview.tableview.view') && $user->isAdmin()) {
            return true;
        }

        return $tableview->user_id == user_id() && $tableview->user_type == user_type();
    }

    /**
     * Determine if the given user can create a tableview.
     *
     * @param UserPolicy $user
     * @param Tableview $tableview
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('tableview.tableview.create');
    }

    /**
     * Determine if the given user can update the given tableview.
     *
     * @param UserPolicy $user
     * @param Tableview $tableview
     *
     * @return bool
     */
    public function update(UserPolicy $user, Tableview $tableview)
    {
        if ($user->canDo('tableview.tableview.edit') && $user->isAdmin()) {
            return true;
        }

        return $tableview->user_id == user_id() && $tableview->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given tableview.
     *
     * @param UserPolicy $user
     * @param Tableview $tableview
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Tableview $tableview)
    {
        return $tableview->user_id == user_id() && $tableview->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given tableview.
     *
     * @param UserPolicy $user
     * @param Tableview $tableview
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Tableview $tableview)
    {
        if ($user->canDo('tableview.tableview.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tableview.
     *
     * @param UserPolicy $user
     * @param Tableview $tableview
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Tableview $tableview)
    {
        if ($user->canDo('tableview.tableview.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
